@@ -22,7 +22,7 @@ namespace Plasma
 {
 }
 
-//Theme selector code by Andre Duffeck (modified to add package description)
+// Theme selector code by Andre Duffeck (modified to add package description)
 class ThemeInfo
 {
 public:
@@ -39,11 +39,12 @@ class LnfListModel : public QAbstractListModel
     Q_OBJECT
     Q_PROPERTY(int count READ count NOTIFY countChanged)
 public:
-    enum { PackageNameRole = Qt::UserRole,
-           PackageDescriptionRole = Qt::UserRole + 1,
-           PackageAuthorRole = Qt::UserRole + 2,
-           PackageVersionRole = Qt::UserRole + 3
-         };
+    enum {
+        PackageNameRole = Qt::UserRole,
+        PackageDescriptionRole = Qt::UserRole + 1,
+        PackageAuthorRole = Qt::UserRole + 2,
+        PackageVersionRole = Qt::UserRole + 3,
+    };
 
     explicit LnfListModel(QObject *parent = nullptr);
     ~LnfListModel() override;
@@ -71,5 +72,4 @@ private:
     QList<ThemeInfo> m_themes;
 };
 
-
 #endif
